@@ -32,15 +32,18 @@ namespace GtkSharp.Generation {
 		private ReturnValue retval;
 
 		private string call;
-		private string protection = "public";
 		private bool is_get, is_set;
 		private bool deprecated = false;
 
 		public Method (XmlElement elem, ClassBase container_type) : base (elem, container_type)
 		{
 			this.retval = new ReturnValue (elem["return-type"]);
-			if (!container_type.IsDeprecated && elem.HasAttribute ("deprecated"))
-				deprecated = elem.GetAttribute ("deprecated") == "1";
+			
+			if (!container_type.IsDeprecated && elem.HasAttribute ("deprecated")) {
+				string attr = elem.GetAttribute ("deprecated");
+				deprecated = attr == "1" || attr == "true";
+			}
+			
 			if (Name == "GetType")
 				Name = "GetGType";
 		}
@@ -63,15 +66,6 @@ namespace GtkSharp.Generation {
 			}
 		}
 
-		public string Protection {
-			get {
-				return protection;
-			}
-			set {
-				protection = value;
-			}
-		}
-
 		public string ReturnType {
 			get {
 				return retval.CSType;
@@ -235,8 +229,8 @@ namespace GtkSharp.Generation {
 			if (IsDeprecated)
 				gen_info.Writer.WriteLine("\t\t[Obsolete]");
 			gen_info.Writer.Write("\t\t");
-			if (protection != "")
-				gen_info.Writer.Write("{0} ", protection);
+			if (Protection != "")
+				gen_info.Writer.Write("{0} ", Protection);
 			GenerateDeclCommon (gen_info.Writer, implementor);
 
 			if (is_get || is_set)
