@@ -4,6 +4,8 @@
 //
 // (c) 2001-2003 Mike Kestner, Novell, Inc.
 
+[assembly:GLib.IgnoreClassInitializers]
+
 namespace GtkSamples {
 
 	using Gtk;
@@ -29,6 +31,11 @@ namespace GtkSamples {
 		}
 	}
 
+	[Binding (Gdk.Key.Escape, "HandleBinding", "Escape")]
+	[Binding (Gdk.Key.Left, "HandleBinding", "Left")]
+	[Binding (Gdk.Key.Right, "HandleBinding", "Right")]
+	[Binding (Gdk.Key.Up, "HandleBinding", "Up")]
+	[Binding (Gdk.Key.Down, "HandleBinding", "Down")]
 	public class MyButton : Gtk.Button {
 
 		public MyButton () : base ("I'm a subclassed button") {}
@@ -37,5 +44,10 @@ namespace GtkSamples {
 		{
 			Console.WriteLine ("Button::Clicked default handler fired.");
 		}
+
+		private void HandleBinding (string text)
+		{
+			Console.WriteLine ("Got a bound keypress: " + text);
+		}
 	}
 }
